import("seisplotjs").then(seisplotjs => {
  import("../pkg/index.js").then(ironecho => {
    function dbg(s) {
      seisplotjs.d3.select("pre#debug").text(s);
    }
    let graph;
    const seisConfig = new seisplotjs.seismographconfig.SeismographConfig();
    seisConfig.doMarkers = true;
    seisplotjs.d3.select("div.seisConfig").selectAll("*").remove();
    seisplotjs.seismographconfig.createEditor(seisplotjs.d3.select("div.seisConfig"),
                                            seisConfig,
                                            () => {if (graph) {graph.draw();};});


    const origModStr = `16
6.96 6.60 3.65 2.90 1456.00 600.00 10000.00 0.00 10000.00 0.00
5.96 7.12 3.92 3.05 1350.00 600.00 10000.00 0.00 10000.00 0.00
13.59 8.13 4.50 3.39 1446.00 600.00 10000.00 0.00 10000.00 0.00
13.62 8.15 4.51 3.40 1446.00 600.00 10000.00 0.00 10000.00 0.00
20.16 8.15 4.51 3.40 1447.00 600.00 10000.00 0.00 10000.00 0.00
20.22 8.17 4.52 3.41 195.00 80.00 10000.00 0.00 10000.00 0.00
17.75 8.17 4.52 3.42 195.00 80.00 10000.00 0.00 10000.00 0.00
17.80 8.20 4.54 3.43 195.00 80.00 10000.00 0.00 10000.00 0.00
17.85 8.19 4.53 3.43 195.00 80.00 10000.00 0.00 10000.00 0.00
17.90 8.23 4.55 3.45 195.00 80.00 10000.00 0.00 10000.00 0.00
17.95 8.22 4.54 3.45 195.00 80.00 10000.00 0.00 10000.00 0.00
18.00 8.25 4.56 3.46 195.00 80.00 10000.00 0.00 10000.00 0.00
18.05 8.24 4.56 3.46 195.00 80.00 10000.00 0.00 10000.00 0.00
18.10 8.28 4.58 3.48 195.00 80.00 10000.00 0.00 10000.00 0.00
15.56 8.97 4.85 3.59 365.00 143.00 10000.00 0.00 10000.00 0.00
0.00 8.98 4.85 3.60 365.00 143.00 10000.00 0.00 10000.00 0.00
0.2 .25 0.285 0.30 1.0
0.0 0.5 0.5 1024
1321.1 199.5
1
10.0
0
0.0 0.707 -0.707 0.0 0.0 0.0`;

    let model = ironecho.gen_model_from_string(origModStr);
    seisplotjs.d3.select("input#npts").property("value", model.params.num_points);
    seisplotjs.d3.select("input#distance").property("value", model.params.distance);
    seisplotjs.d3.select("textarea#layers").property("value", origModStr);

    seisplotjs.d3.select("pre#model").text(model.to_string());

    seisplotjs.d3.select("#calc").on("click", () => {
      let before = seisplotjs.moment.utc();
      let modStr = seisplotjs.d3.select("#layers").property("value");
      let npts = parseInt(seisplotjs.d3.select("#npts").property("value"));
      if (npts) {model.setNumPoints(npts);}
      let dist = parseFloat(seisplotjs.d3.select("#distance").property("value"));
      if (dist) {model.setDistance(dist);}
      seisplotjs.d3.select("pre#model").text(model.to_string());
      seisplotjs.d3.select("div#seismograph").selectAll("svg").remove();
      seisplotjs.d3.select("div#seismograph").selectAll("textarea").remove();
      seisplotjs.d3.select("div#seismograph").select("p").text("Waiting patiently...");
    Promise.resolve().then( () => {
      return ironecho.calc_it(model);
    }).then(freqRes => {
      seisplotjs.d3.select("div#seismograph").select("p").text("");
      let after = seisplotjs.moment.utc();
      const dur = new seisplotjs.util.StartEndDuration(before, after).duration;
      dbg(`${dur} seconds`);
      console.log("got result");
      const reduceVel= parseFloat(seisplotjs.d3.select("input#reduce").property("value"));
      const offset = parseFloat(seisplotjs.d3.select("input#offset").property("value"));

      const freqLen = freqRes.freq_len();
      let seisdataZ = seisplotjs.fft.inverseDFT(freqRes.z(reduceVel, offset), freqLen);
      let seisdataR = seisplotjs.fft.inverseDFT(freqRes.r(reduceVel, offset), freqLen);
      let seisdataT = seisplotjs.fft.inverseDFT(freqRes.t(reduceVel, offset), freqLen);
      console.log(seisdataZ);
      const sps = .5/(model.params.fmax);
      const zeroTime = seisplotjs.moment.utc("2000-01-01T00:00:00");
      const timeReduce = freqRes.time_reduce(reduceVel, offset);
      const seisStart = seisplotjs.moment.utc(zeroTime).add(seisplotjs.moment.duration(timeReduce, 'seconds'));
      seisplotjs.d3.select("pre#redvel").text(`reduce: ${reduceVel} offset: ${offset}  timeRed: ${timeReduce}  start: ${seisStart}`);

      let tw = new seisplotjs.util.StartEndDuration(seisStart, null, seisdataZ.length/sps);
      let segZ = new seisplotjs.seismogram.SeismogramSegment(seisdataZ, 1, tw.startTime);
      let segR = new seisplotjs.seismogram.SeismogramSegment(seisdataR, 1, tw.startTime);
      let segT = new seisplotjs.seismogram.SeismogramSegment(seisdataT, 1, tw.startTime);
      segZ.networkCode = "XX";
      segZ.stationCode = "STA";
      segZ.locationCode = "00";
      segZ.channelCode = "LHZ";
      let seismogramZ = new seisplotjs.seismogram.Seismogram(segZ);
      segR.networkCode = "XX";
      segR.stationCode = "STA";
      segR.locationCode = "00";
      segR.channelCode = "LHR";
      let seismogramR = new seisplotjs.seismogram.Seismogram(segR);
      segT.networkCode = "XX";
      segT.stationCode = "STA";
      segT.locationCode = "00";
      segT.channelCode = "LHT";
      let seismogramT = new seisplotjs.seismogram.Seismogram(segT);

      let div = seisplotjs.d3.select('div#seismograph');
      seisConfig.margin.top = 25;
      let seismogramDataList = [];
      seismogramDataList.push( seisplotjs.seismogram.SeismogramDisplayData.fromSeismogram(seismogramZ));
      seismogramDataList.push( seisplotjs.seismogram.SeismogramDisplayData.fromSeismogram(seismogramR));
      seismogramDataList.push( seisplotjs.seismogram.SeismogramDisplayData.fromSeismogram(seismogramT));
      seismogramDataList[0].addMarker({
        markertype: 'predicted',
        name: "origin",
        time: zeroTime
      });

      graph = new seisplotjs.seismograph.Seismograph(div, seisConfig, seismogramDataList);
      graph.draw();

    }).catch(err => {
      let stack = err.stack ? err.stack : "";
      seisplotjs.d3.select("div#seismograph").append("textarea").attr("rows", "20").style("width", "100%").property("value",err.name+"\n "+err.message+"\n"+stack);
      console.error(err);
    });

  });
  }).catch(console.error);

}).catch(console.error);
